@@ -299,8 +299,9 @@ class SlackInput(InputChannel):
                 return True
             elif action_type:
                 logger.warning(
-                    "Received input from a Slack interactive component of type "
-                    f"'{payload['actions'][0]['type']}', for which payload parsing is not yet supported."
+                    f"Received input from a Slack interactive component of type "
+                    f"'{payload['actions'][0]['type']}', "
+                    f"for which payload parsing is not yet supported."
                 )
         return False
 
@@ -517,7 +518,8 @@ class SlackInput(InputChannel):
 
                 if not self._is_supported_channel(output, metadata):
                     logger.warning(
-                        f"Received message on unsupported channel: {metadata['out_channel']}"
+                        f"Received message on unsupported "
+                        f"channel: {metadata['out_channel']}"
                     )
                     return response.text("channel not supported.")
 
