@@ -1,10 +1,9 @@
 from typing import List, Text
 
 from rasa.nlu.tokenizers.tokenizer import Token, Tokenizer
-from rasa.nlu.training_data import Message
+from rasa.shared.nlu.training_data.message import Message
 
-from rasa.nlu.constants import TOKENS_NAMES, MESSAGE_ATTRIBUTES
-from rasa.utils.io import DEFAULT_ENCODING
+from rasa.shared.utils.io import DEFAULT_ENCODING
 
 
 class MitieTokenizer(Tokenizer):
@@ -14,6 +13,8 @@ class MitieTokenizer(Tokenizer):
         "intent_tokenization_flag": False,
         # Symbol on which intent should be split
         "intent_split_symbol": "_",
+        # Regular expression to detect tokens
+        "token_pattern": None,
     }
 
     @classmethod
@@ -32,7 +33,7 @@ class MitieTokenizer(Tokenizer):
             for token, offset in tokenized
         ]
 
-        return tokens
+        return self._apply_token_pattern(tokens)
 
     def _token_from_offset(
         self, text: bytes, offset: int, encoded_sentence: bytes
