@@ -1,6 +1,6 @@
 import typing
 import logging
-from typing import Any, Dict, List, Optional, Text, Tuple, Union
+from typing import Any, Dict, List, Optional, Text, Tuple
 
 import rasa.shared.utils.io
 import rasa.utils.train_utils
@@ -46,13 +46,23 @@ class SpacyNLP(Component):
         """Try loading the model, catching the OSError if missing."""
         import spacy
 
+        if not spacy_model_name:
+            raise InvalidModelError(
+                f"Missing model configuration for `SpacyNLP` in `config.yml`.\n"
+                f"You must pass a model to the `SpacyNLP` component explicitly.\n"
+                f"For example:\n"
+                f"- name: SpacyNLP\n"
+                f"  model: en_core_web_md\n"
+                f"More informaton can be found on {DOCS_URL_COMPONENTS}#spacynlp"
+            )
+
         try:
             return spacy.load(spacy_model_name, disable=["parser"])
         except OSError:
             raise InvalidModelError(
                 f"Please confirm that {spacy_model_name} is an available spaCy model. "
-                f"You need to download one upfront. For example:\npython -m spacy download "
-                f"en_core_web_md\n"
+                f"You need to download one upfront. For example:\n"
+                f"python -m spacy download en_core_web_md\n"
                 f"More informaton can be found on {DOCS_URL_COMPONENTS}#spacynlp"
             )
 
@@ -68,10 +78,7 @@ class SpacyNLP(Component):
         component_config = rasa.utils.train_utils.override_defaults(
             cls.defaults, component_config
         )
-
-        spacy_model_name = cls._check_model_fallback(
-            component_config.get("model"), config.language, warn=True
-        )
+        spacy_model_name = component_config.get("model")
 
         logger.info(f"Trying to load spacy model with name '{spacy_model_name}'")
 
@@ -85,61 +92,10 @@ class SpacyNLP(Component):
         cls, component_meta: Dict[Text, Any], model_metadata: "Metadata"
     ) -> Optional[Text]:
 
-        spacy_model_name = cls._check_model_fallback(
-            component_meta.get("model"), model_metadata.language, warn=False
-        )
+        spacy_model_name = component_meta.get("model")
 
         return cls.name + "-" + spacy_model_name
 
-    @staticmethod
-    def _check_model_fallback(
-        spacy_model_name: Union[str, None], language_name: str, warn: bool = False
-    ) -> Text:
-        """This method checks if the `spacy_model_name` is missing.
-
-        If it is missing, we will attempt a fallback. This feature is a measure
-        to support spaCy 3.0 without breaking on users. In the future
-        spaCy will no longer support `spacy link`.
-        """
-        if not spacy_model_name:
-            fallback_mapping = {
-                "zh": "zh_core_web_md",
-                "da": "da_core_news_md",
-                "nl": "nl_core_news_md",
-                "en": "en_core_web_md",
-                "fr": "fr_core_news_md",
-                "de": "de_core_news_sm",
-                "el": "el_core_news_md",
-                "it": "it_core_news_md",
-                "ja": "ja_core_news_md",
-                "lt": "lt_core_news_md",
-                "mk": "mk_core_news_md",
-                "nb": "nb_core_news_md",
-                "pl": "pl_core_news_md",
-                "pt": "pt_core_news_md",
-                "ro": "ro_core_news_md",
-                "ru": "ru_core_news_md",
-                "es": "es_core_news_md",
-            }
-            if language_name not in fallback_mapping.keys():
-                raise InvalidModelError(
-                    f"There is no fallback model for language '{language_name}'. "
-                    f"Please add a `model` property to `SpacyNLP` manually to prevent this. "
-                    f"More informaton can be found on {DOCS_URL_COMPONENTS}#spacynlp"
-                )
-
-            spacy_model_name = fallback_mapping[language_name]
-            if warn:
-                message = (
-                    f"SpaCy model is not properly configured! Please add a `model` property to `SpacyNLP`. "
-                    f"Will use '{spacy_model_name}' as a fallback spaCy model. "
-                    f"This fallback will be deprecated in Rasa 3.0"
-                )
-                rasa.shared.utils.io.raise_deprecation_warning(
-                    message=message, docs=f"{DOCS_URL_COMPONENTS}#spacynlp"
-                )
-        return spacy_model_name
-
     def provide_context(self) -> Dict[Text, Any]:
         """Creates a context dictionary from spaCy nlp object."""
         return {"spacy_nlp": self.nlp}
@@ -302,11 +258,7 @@ class SpacyNLP(Component):
         if cached_component:
             return cached_component
 
-        model_name = cls._check_model_fallback(
-            meta.get("model"), model_metadata.language, warn=True
-        )
-
-        nlp = cls.load_model(model_name)
+        nlp = cls.load_model(meta.get("model"))
         cls.ensure_proper_language_model(nlp)
         return cls(meta, nlp)
 
